'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getAuthFunction = getAuthFunction;
var promisedFunction = void 0;

var debug = require('debug')('lambda-custom-authorizer-middleware');

/**
 * Get promisified lambda function by path and exported handler name
 * @param {String} handlerPath Path on local file system to the function
 * @param {String} handlerName Name of the exported function in provided path
 * @return {(function(*=): Promise)|*} Promisified function
 */
function getAuthFunction(handlerPath, handlerName) {
  if (promisedFunction) {
    debug(`[handler-loaded]`);
    return promisedFunction;
  }

  debug(`[handler-loading][path:${handlerPath}][name:${handlerName}]`);
  var cbFunction = require(handlerPath)[handlerName];

  promisedFunction = function promisedFunction(event) {
    return new Promise(function (resolve, reject) {
      cbFunction(event, {}, function (error, response) {
        if (error) {
          return reject(error);
        }

        return resolve(response);
      });
    });
  };
  debug(`[handler-loaded]`);

  return promisedFunction;
}